/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.cli;

// for exceptions
import com.rempl.api.RuntimeProblem;

// for manifest manipulation
import java.net.URL;

// for manifest manipulation
import java.util.jar.Attributes;
import java.util.jar.Manifest;

/**
 * Entry point of the JAR.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: Version.java 776 2011-03-18 22:35:07Z yegor256@yahoo.com $
 */
public final class Version {

    /**
     * Get version of the product.
     * @return The version
     * @todo #9 In case of absence of attributes in the MANIFEST.MF we
     *          have to report properly with something like "unknown".
     *          In the current implementation the response looks ugly.
     */
    public String get() {
        final URL url = this.getClass().getResource("/META-INF/MANIFEST.MF");
        if (url == null) {
            throw RuntimeProblem.make("manifest.mf not found");
        }
        Manifest mfst;
        try {
            mfst = new Manifest(url.openStream());
        } catch (java.io.IOException ex) {
            throw RuntimeProblem.make(ex);
        }
        final Attributes attrs = mfst.getMainAttributes();
        return String.format(
            "REMPL %s rev%s of %s",
            (String) attrs.get("REMPL-Version"),
            (String) attrs.get("REMPL-Revision"),
            (String) attrs.get("REMPL-Date")
        );
    }

}
